==> csaf-2023.11.27.tar.gz: csaf-2023.11.27/README.md <==
# CSAF

Common Security Advisory Framework (CSAF) Verification, Validation, and Application Programming Interface (API).

[![License](https://git.sr.ht/~sthagen/csaf/blob/default/docs/badges/license-spdx-mit.svg)](https://git.sr.ht/~sthagen/csaf/tree/default/item/LICENSE)
[![Country of Origin](https://git.sr.ht/~sthagen/csaf/blob/default/docs/badges/country-of-origin-name-switzerland-neutral.svg)](https://git.sr.ht/~sthagen/csaf/tree/default/item/COUNTRY-OF-ORIGIN)
[![Export Classification Control Number (ECCN)](https://git.sr.ht/~sthagen/csaf/blob/default/docs/badges/export-control-classification-number_eccn-ear99-neutral.svg)](https://git.sr.ht/~sthagen/csaf/tree/default/item/EXPORT-CONTROL-CLASSIFICATION-NUMBER)
[![Configuration](https://git.sr.ht/~sthagen/csaf/blob/default/docs/badges/configuration-sbom.svg)](https://git.sr.ht/~sthagen/csaf/tree/default/item/docs/third-party/README.md)

[![Version](https://git.sr.ht/~sthagen/csaf/blob/default/docs/badges/latest-release.svg)](https://pypi.python.org/pypi/csaf/)
[![Downloads](https://git.sr.ht/~sthagen/csaf/blob/default/docs/badges/downloads-per-month.svg)](https://pepy.tech/project/csaf)
[![Python](https://git.sr.ht/~sthagen/csaf/blob/default/docs/badges/python-versions.svg)](https://pypi.python.org/pypi/csaf/)
[![Maintenance Status](https://git.sr.ht/~sthagen/csaf/blob/default/docs/badges/commits-per-year.svg)](https://git.sr.ht/~sthagen/csaf/log)

In this project the attempt is made, to provide API and tools to support the CSAF communities from a single repository in the easy to prototype python language.

If, and when this endeavor succeeds, other languages can easily derive form the approach (as long as these offer similar capabilties to keep the effort in check).

**Note**: CSAF predecessor CVRF versions 1.1 and 1.2 are out of scope.

## Documentation

User and developer [documentation of csaf](https://codes.dilettant.life/docs/csaf).

## Bug Tracker

Any feature requests or bug reports shall go to the [todos of csaf](https://todo.sr.ht/~sthagen/csaf).

## Primary Source repository

The main source of `csaf` is on a mountain in central Switzerland.
We use distributed version control (git).
There is no central hub.
Every clone can become a new source for the benefit of all.
The preferred public clones of `csaf` are:

* [on codeberg](https://codeberg.org/sthagen/csaf) - a democratic community-driven, non-profit software development platform operated by Codeberg e.V.
* [at sourcehut](https://git.sr.ht/~sthagen/csaf) - a collection of tools useful for software development.

## Contributions

Please do not submit "pull requests" (I found no way to disable that "feature" on GitHub).
If you like to share small changes under the repositories license please kindly do so by sending a patchset.
You can either send such a patchset per email using [git send-email](https://git-send-email.io) or 
if you are a sourcehut user by selecting "Prepare a patchset" on the summary page of your fork at [sourcehut](https://git.sr.ht/).

## Support

Please kindly submit issues at https://todo.sr.ht/~sthagen/csaf or write plain text email to ~sthagen/csaf@lists.sr.ht to submit patches and request support. Thanks.

## Contributors

In alphabetical order:

* Anthony Harrison
* Jacco Ligthart

## Status

Experimental

**Note**: The default branch is `default`.

==> csaf-2024.12.18.tar.gz: csaf-2024.12.18/README.md <==
# CSAF

Common Security Advisory Framework (CSAF) Verification, Validation, and Application Programming Interface (API).

[![License](https://git.sr.ht/~sthagen/csaf/blob/default/docs/badges/license-spdx-mit.svg)](https://git.sr.ht/~sthagen/csaf/tree/default/item/LICENSE)
[![Country of Origin](https://git.sr.ht/~sthagen/csaf/blob/default/docs/badges/country-of-origin-name-switzerland-neutral.svg)](https://git.sr.ht/~sthagen/csaf/tree/default/item/COUNTRY-OF-ORIGIN)
[![Export Classification Control Number (ECCN)](https://git.sr.ht/~sthagen/csaf/blob/default/docs/badges/export-control-classification-number_eccn-ear99-neutral.svg)](https://git.sr.ht/~sthagen/csaf/tree/default/item/EXPORT-CONTROL-CLASSIFICATION-NUMBER)
[![Configuration](https://git.sr.ht/~sthagen/csaf/blob/default/docs/badges/configuration-sbom.svg)](https://git.sr.ht/~sthagen/csaf/tree/default/item/docs/third-party/README.md)

[![Version](https://git.sr.ht/~sthagen/csaf/blob/default/docs/badges/latest-release.svg)](https://pypi.python.org/pypi/csaf/)
[![Downloads](https://git.sr.ht/~sthagen/csaf/blob/default/docs/badges/downloads-per-month.svg)](https://pepy.tech/project/csaf)
[![Python](https://git.sr.ht/~sthagen/csaf/blob/default/docs/badges/python-versions.svg)](https://pypi.python.org/pypi/csaf/)
[![Maintenance Status](https://git.sr.ht/~sthagen/csaf/blob/default/docs/badges/commits-per-year.svg)](https://git.sr.ht/~sthagen/csaf/log)

In this project the attempt is made, to provide API and tools to support the CSAF communities from a single repository in the easy to prototype python language.

If, and when this endeavor succeeds, other languages can easily derive form the approach (as long as these offer similar capabilties to keep the effort in check).

**Note**: CSAF predecessor CVRF versions 1.1 and 1.2 are out of scope.

## Documentation

User and developer [documentation of csaf](https://codes.dilettant.life/docs/csaf).

## Bug Tracker

Any feature requests or bug reports shall go to the [todos of csaf](https://todo.sr.ht/~sthagen/csaf).

## Primary Source repository

The main source of `csaf` is on a mountain in central Switzerland.
We use distributed version control (git).
There is no central hub.
Every clone can become a new source for the benefit of all.
The preferred public clone of `csaf` is:

* [at sourcehut](https://git.sr.ht/~sthagen/csaf) - a collection of tools useful for software development.

## Contributions

Please do not submit "pull requests" (I found no way to disable that "feature" on GitHub).
If you like to share small changes under the repositories license please kindly do so by sending a patchset.
You can either send such a patchset per email using [git send-email](https://git-send-email.io) or 
if you are a sourcehut user by selecting "Prepare a patchset" on the summary page of your fork at [sourcehut](https://git.sr.ht/).

## Support

Please kindly submit issues at https://todo.sr.ht/~sthagen/csaf or write plain text email to ~sthagen/csaf@lists.sr.ht to submit patches and request support. Thanks.

## Contributors

In alphabetical order:

* Anthony Harrison
* Jacco Ligthart
* Jiří Pešík

## Status

Experimental

**Note**: The default branch is `default`.
